package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"fmt"
	"xorm.io/xorm"
)

func NewEggEnergyFundDataDb(engine *xorm.Engine) dao.EggEnergyFundDataDao {
	return &EggEnergyFundDataDb{Db: engine}
}

type EggEnergyFundDataDb struct {
	Db *xorm.Engine
}

func (e EggEnergyFundDataDb) EggEnergyFundDataFindAndCount(page, limit, kind int, startAt, endAt string) ([]model.EggEnergyFundData, int64, error) {
	var m []model.EggEnergyFundData
	session := e.Db.Where("")
	if kind > 0 {
		session = session.Where("kind = ?", kind)
	}
	if startAt != "" {
		session = session.Where("start_at >= ?", startAt)
	}
	if endAt != "" {
		session = session.Where("end_at <= ?", endAt)
	}
	total, err := session.Limit(limit, (page-1)*limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, zhios_order_relate_logx.Error(err.Error())
	}
	return m, total, nil
}

func (e EggEnergyFundDataDb) EggEnergyFundDataInsert(eggEnergyFundData *model.EggEnergyFundData) (int, error) {
	_, err := e.Db.InsertOne(eggEnergyFundData)
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err.Error())
	}
	return eggEnergyFundData.Id, nil
}

func (e EggEnergyFundDataDb) EggEnergyFundDataFindNotFinish() ([]model.EggEnergyFundData, error) {
	var m []model.EggEnergyFundData
	err := e.Db.Where("balance_times > ?", 0).Find(&m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err.Error())
	}
	return m, nil
}

func (e EggEnergyFundDataDb) EggEnergyFundDataUpdateBySession(session *xorm.Session, m model.EggEnergyFundData, forceColumns ...string) (int64, error) {
	affected, err := session.ID(m.Id).Cols(forceColumns...).Update(&m)
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err.Error())
	}

	return affected, nil
}

func (e EggEnergyFundDataDb) EggEnergyFundDataGetOneByParams(params map[string]interface{}) (*model.EggEnergyFundData, error) {
	var m model.EggEnergyFundData
	var query = fmt.Sprintf("%s =?", params["key"])
	if has, err := e.Db.Where(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}
